@@ -48,7 +48,7 @@
 #define DONTSAVE 1
 #define CANCEL 2
 
-const gchar* maintopic = N_("GNOME Soundrecorder:");
+const gchar* maintopic = N_("Sound Recorder:");
 
 const gchar* temp_filename_record = "untitled.raw";
 const gchar* temp_filename_play = "untitled.wav";
@@ -64,8 +64,7 @@ gboolean file_changed = FALSE;
 static guint play_id;
 static guint record_id;
 
-///////////////////////////////////////////////////////////////////
-// ------------------- Callbacks ------------------------------- //
+/* ------------------- Callbacks ------------------------------- */
 void
 on_record_activate_cb (GtkWidget* widget, gpointer data)
 {
@@ -76,6 +75,9 @@ on_record_activate_cb (GtkWidget* widget, gpointer data)
 	grecord_set_sensitive_progress ();
 	file_changed = TRUE;
 
+	/* Reset record-time and stuff */
+	UpdateStatusbarRecord (TRUE);
+
 	RecEng.pid = fork ();
 	if (RecEng.pid == 0) {
 		
@@ -92,7 +94,7 @@ on_record_activate_cb (GtkWidget* widget, gpointer data)
 
 	record_id = gtk_timeout_add (1000,
 				     (GtkFunction) UpdateStatusbarRecord,
-				     NULL);
+				     FALSE);
 }
 
 void
@@ -226,7 +228,7 @@ on_new_activate_cb (GtkWidget* widget, gpointer data)
 	grecord_set_sensitive_nofile ();
 
 	gtk_range_set_adjustment (GTK_RANGE (grecord_widgets.Statusbar), GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 1000, 1, 1, 0)));
-	gtk_range_slider_update (GTK_RANGE (grecord_widgets.Statusbar));
+/*  	gtk_range_slider_update (GTK_RANGE (grecord_widgets.Statusbar)); */
 
 	/* Reload configuration */
 	load_config_file ();
@@ -506,8 +508,7 @@ on_undoall_activate_cb (GtkWidget* widget, gpointer data)
 	g_free (temp_string);
 }
 
-///////////////////////////////////////////////////////////////
-// --------------------- Help functions -------------------- //
+/* --------------------- Help functions -------------------- */
 void
 record_sound (void)
 {
@@ -518,7 +519,7 @@ record_sound (void)
 	gint length = 0;
 	
 	gint bits = ESD_BITS16;
-	gint channels = ESD_STEREO;
+	gint esd_channels = ESD_STEREO;
 	gint mode = ESD_STREAM;
 	gint func = ESD_RECORD;
 	esd_format_t format = 0;
@@ -534,14 +535,14 @@ record_sound (void)
 	g_free (tfile);
 
 	/* Set up bits, channels etc after the preferences */
-	if (channels == 1)
-		channels = ESD_MONO;
+	if (esd_channels == 1)
+		esd_channels = ESD_MONO;
 	if (audioformat != 0)
 		bits = ESD_BITS8;
 
 	rate = atoi (samplerate);
 
-	format = bits | channels | mode | func;
+	format = bits | esd_channels | mode | func;
 	sock = esd_record_stream_fallback (format, rate, host, name);
 	
 	if (sock <= 0)
@@ -713,7 +714,7 @@ save_filename (GtkFileSelection* selector, gpointer file_selector)
 		gchar* tempstring;
 		gchar* string = g_strdup ((char *) strrchr (active_file, '/'));
 		string[1] = ' ';
-		temp_string = g_strconcat (_(maintopic), string, NULL);
+		tempstring = g_strconcat (_(maintopic), string, NULL);
 		gtk_window_set_title (GTK_WINDOW (grecord_widgets.grecord_window), tempstring);
 		g_free (tempstring);
 		g_free (string);
@@ -813,18 +814,25 @@ UpdateStatusbarPlay (gboolean begin)
 	set_min_sec_time (countersec, FALSE);
 
 	gtk_range_set_adjustment (GTK_RANGE (grecord_widgets.Statusbar), GTK_ADJUSTMENT (gtk_adjustment_new (counter, 0, 1000, 1, 1, 0)));
-	gtk_range_slider_update (GTK_RANGE (grecord_widgets.Statusbar));
+/*  	gtk_range_slider_update (GTK_RANGE (grecord_widgets.Statusbar)); */
 	
 	return TRUE;
 }
 
 guint
-UpdateStatusbarRecord (gpointer data)
+UpdateStatusbarRecord (gboolean begin)
 {
 	static gint counter = 0;
 	static gint timeout = 0;
 	static gint countersec = 0;
 
+	if (begin) {
+		counter = 0.00;
+		timeout = 0;
+		countersec = 0;
+		return TRUE;
+	}
+
 	/* Timeout */
 	if (counter >= 1000) {
 		if (stop_on_timeout) {
@@ -905,7 +913,7 @@ UpdateStatusbarRecord (gpointer data)
 	counter += (int) 1000 / timeout;
 
 	gtk_range_set_adjustment (GTK_RANGE (grecord_widgets.Statusbar), GTK_ADJUSTMENT (gtk_adjustment_new (counter, 0, 1000, 1, 1, 0)));
-	gtk_range_slider_update (GTK_RANGE (grecord_widgets.Statusbar));
+/*  	gtk_range_slider_update (GTK_RANGE (grecord_widgets.Statusbar)); */
 
 	return TRUE;
 }
